unit VCLdemo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, WiNRADiO, ExtCtrls, ComCtrls, Gauges;

type
  TVCDemo = class(TForm)
    WiNRADiO1: TWiNRADiO;
    BtnMode: TButton;
    BtnAtten: TButton;
    BtnMute: TButton;
    BtnPower: TButton;
    BtnQuit: TButton;
    HeadingLabel: TLabel;
    ModeValue: TLabel;
    AttenValue: TLabel;
    MuteValue: TLabel;
    PowerValue: TLabel;
    FreqValue: TEdit;
    BFOValue: TEdit;
    SignalGauge: TGauge;
    SignalLabel: TLabel;
    VolValue: TLabel;
    VolUpDown: TUpDown;
    BFOUpDown: TUpDown;
    FreqLabel: TLabel;
    BFOLabel: TLabel;
    VolumeLabel: TLabel;
    procedure BtnQuitClick(Sender: TObject);
    procedure BtnModeClick(Sender: TObject);
    procedure BtnMuteClick(Sender: TObject);
    procedure BtnPowerClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure WiNRADiO1MuteChange(Sender: TObject);
    procedure WiNRADiO1PowerChange(Sender: TObject);
    procedure WiNRADiO1AttenChange(Sender: TObject);
    procedure BtnAttenClick(Sender: TObject);
    procedure WiNRADiO1ModeChange(Sender: TObject);
    procedure VolUpDownClick(Sender: TObject; Button: TUDBtnType);
    procedure WiNRADiO1VolumeChange(Sender: TObject);
    procedure BFOValueChange(Sender: TObject);
    procedure BFOUpDownClick(Sender: TObject; Button: TUDBtnType);
    procedure FreqValueChange(Sender: TObject);
    procedure WiNRADiO1SignalChange(Sender: TObject);
  private
    { Private declarations }
    Procedure DisplayMode;
    Procedure DisplayAtten;
    Procedure DisplayMute;
    Procedure DisplayPower;
    Procedure DisplayVolume;
    Procedure DisplayBFOOffset;
    Procedure DisplayFrequency;
    Procedure DisplaySignalLevel;
    Procedure CheckBFOValue;
  public
    { Public declarations }
  end;

var
  VCDemo: TVCDemo;

implementation

{$R *.DFM}
Procedure TVCDemo.DisplayMode;
{
  Procedure displays the current mode
}
Begin {DisplayMode}
  ModeValue.Caption := WiNRADiO1.ModeToStr(LoByte(WiNRADiO1.Mode))
End;  {DisplayMode}

Procedure TVCDemo.DisplayAtten;
{
  Procedure displays the current Attenuator setting
}
Begin {DisplayAtten}
  If WiNRADiO1.Attenuator Then
    AttenValue.Caption := 'Local'
  Else
    AttenValue.Caption := 'DX'
End;  {DisplayAtten}

Procedure TVCDemo.DisplayMute;
{
  Procedure displays the mute status
}
Begin {DisplayMute}
  If WiNRADiO1.Mute Then
    MuteValue.Caption := 'ON'
  Else
    MuteValue.Caption := 'OFF'
End;  {DisplayMute}

Procedure TVCDemo.DisplayPower;
{
  Procedure displays the Power status
}
Begin {DisplayPower}
  If WiNRADiO1.Power Then
    PowerValue.Caption := 'ON'
  Else
    PowerValue.Caption := 'OFF'
End;  {DisplayPower}

Procedure TVCDemo.DisplayVolume;
{
  Procedure displays the current volume level
}
Begin {DisplayVolume}
  VolValue.Caption := IntToStr(WiNRADiO1.Volume);
End;  {DisplayVolume}

Procedure TVCDemo.DisplayFrequency;
{
  Procedure displays the current frequency
}
Begin {DisplayFrequency}
  FreqValue.Text := IntToStr(WiNRADiO1.Frequency);
End;  {DisplayFrequency}

Procedure TVCDemo.DisplayBFOOffset;
{
  Procedure display the current BFO Offset value
}
Begin {DisplayBFOOffset}
   BFOValue.Text := IntToStr(WiNRADiO1.CWOffset);
   BFOUpDown.Position := WiNRADiO1.CWOffset
End;  {DisplayBFOOffset}

Procedure TVCDemo.DisplaySignalLevel;
{
  Procedure displays the current Signal Strength
}
Begin {DisplaySignalLevel}
  SignalGauge.Progress := WiNRADiO1.SignalStrength
End;  {DisplaySignalLevel}

Procedure TVCDemo.CheckBFOValue;
{
  Procedure updates the WinRadio BFO Offset from the value
  in the edit box.
}
Var
  iBFO : Integer;
  Code : Integer;

Begin {CheckBFOValue}
   Val(BFOValue.Text, iBFO, Code);
   If (Code<>0) Then
     {Read the value back and re-display}
     DisplayBFOOffset
   Else
     WiNRADiO1.CWOffset := StrToInt(BFOValue.Text)
End;  {CheckBFOValue}

procedure TVCDemo.BtnQuitClick(Sender: TObject);
begin
  Close
end;

procedure TVCDemo.BtnModeClick(Sender: TObject);
Var
  iMode : Integer;
  Modes : Integer;

begin
  Modes := WiNRADiO1.Modes.Count;
  iMode := LoByte(WiNRADiO1.Mode);
  Inc(iMode);
  iMode := iMode MOD Modes;
  WiNRADiO1.Mode := iMode
end;

procedure TVCDemo.BtnMuteClick(Sender: TObject);
begin
  WiNRADiO1.Mute := Not(WiNRADiO1.Mute)
end;

procedure TVCDemo.BtnPowerClick(Sender: TObject);
begin
  WiNRADiO1.Power := Not(WiNRADiO1.Power)
end;

procedure TVCDemo.FormCreate(Sender: TObject);
begin
  {Verify that WinRadio hardware is present}

  {
    NOTE: If WinRadio software is running, WiNRADiO1.Open()
          reports no card(s) found, because WinRadio will
          already have established a handle.
  }
  If Not WiNRADiO1.Open(0) Then
    Begin
      MessageDlg('Could not get a handle to the WiNRADiO card.'+#13#10+
                 'If the WiNRADiO application is running, please'+#13#10+
                 'terminate it and then re-run this program.'+#13#10+#13#10+
                 'This program will now terminate.',
                  mtWarning, [mbOK], 0);
      Application.Terminate
    End;


  {Initialise properties of the WiNRADiO component}
  WiNRADiO1.Frequency := 10000000;
  WiNRADiO1.Mode := LoByte(WiNRADiO1.StrToMode('AM'));
  WiNRADiO1.Attenuator := TRUE;
  WiNRADiO1.Mute := FALSE;
  WiNRADiO1.Power := TRUE;
  WiNRADiO1.Volume := 15;
  WiNRADiO1.CWOffset := 0;

  {Set the bounds on the BFO control}
  BFOUpDown.Min := -WiNRADiO1.RadioInfo.iMaxBFO;
  BFOUpDown.Max := WiNRADiO1.RadioInfo.iMaxBFO;
  BFOUpDown.Position := WiNRADiO1.CWOffset;

  {Set the bounds on the volume control}
  VolUpDown.Max := WiNRADiO1.RadioInfo.iMaxVolume;
  VolUpDown.Position := WiNRADiO1.Volume;
  
  {Initialise all of the displays}
  DisplayMode;
  DisplayAtten;
  DisplayMute;
  DisplayPower;
  DisplayVolume;
  DisplayFrequency;
  DisplaySignalLevel;
end;

procedure TVCDemo.WiNRADiO1MuteChange(Sender: TObject);
begin
  DisplayMute
end;

procedure TVCDemo.WiNRADiO1PowerChange(Sender: TObject);
begin
  DisplayPower
end;

procedure TVCDemo.WiNRADiO1AttenChange(Sender: TObject);
begin
  DisplayAtten
end;

procedure TVCDemo.BtnAttenClick(Sender: TObject);
begin
  WiNRADiO1.Attenuator := Not(WiNRADiO1.Attenuator)
end;

procedure TVCDemo.WiNRADiO1ModeChange(Sender: TObject);
Var
  iMode: Integer;

begin
  {Get the current mode}
  iMode := LoByte(WiNRADiO1.Mode);

  {Set enabled status of BFO}
  BFOUpDown.Enabled := (iMode = 0);

  {Set enabled status of BFO value edit box}
  BFOValue.Enabled := BFOUpDown.Enabled;

  {Display the selected mode}
  DisplayMode
end;

procedure TVCDemo.VolUpDownClick(Sender: TObject; Button: TUDBtnType);
begin
  WiNRADiO1.Volume := VolUpDown.Position;
end;

procedure TVCDemo.WiNRADiO1VolumeChange(Sender: TObject);
begin
  DisplayVolume
end;

procedure TVCDemo.BFOValueChange(Sender: TObject);
begin
  CheckBFOValue
end;

procedure TVCDemo.BFOUpDownClick(Sender: TObject; Button: TUDBtnType);
begin
  DisplayBFOOffset
end;

procedure TVCDemo.FreqValueChange(Sender: TObject);
Var
  dwFreq : LongInt;
  Code : Integer;

begin
  Val(FreqValue.Text, dwFreq, Code);
  If (Code<>0) Then  {Numeric conversion error}
    {Read the value back and re-display}
    DisplayFrequency
  Else
    WiNRADiO1.Frequency := StrToInt(FreqValue.Text);
end;

procedure TVCDemo.WiNRADiO1SignalChange(Sender: TObject);
begin
  DisplaySignalLevel
end;

end.
